/*
 *  NDProcess.h
 *  ProcessesObjectTest
 *
 *  Created by Nathan Day on Mon May 27 2002.
 *  Copyright (c) 2002 Nathan Day. All rights reserved.
 */

#import <Cocoa/Cocoa.h>
#import <Carbon/Carbon.h>

@interface NDProcess : NSObject
{
@private
	ProcessSerialNumber	processSerialNumber;
	ProcessInfoRec			infoRec;
	NSString					* name;
	NSURL						* url;
}

- (id)initWithProcessSerialNumber:(ProcessSerialNumber)aProcessSerialNumber;

- (ProcessSerialNumber)processSerialNumber;

- (BOOL)isFrontProcess;
- (BOOL)isCurrentProcess;
- (BOOL)makeFrontProcess;
- (BOOL)wakeUpProcess;

@end

@interface NDProcess (Construction)

- (id)initWithCurrentProcess;
- (id)initWithFrontProcess;

+ (NSArray *)everyProcess;

+ (NSArray *)everyProcessNamed:(NSString *)aName;		// potentially more than one possible

/*
 * WARRING: all of these methods return an instance that will be reuses
 * unless you retain it.
 */
+ (NDProcess *)processWithProcessSerialNumber:(ProcessSerialNumber)aProcessSerialNumber;
+ (NDProcess *)currentProcess;
+ (NDProcess *)frontProcess;

+ (NDProcess *)firstProcessNamed:(NSString *)aName;		// usually the only one
+ (NDProcess *)processForURL:(NSURL *)aURL;
+ (NDProcess *)processForPath:(NSString *)aPath;

/*
 * WARRING: the instances returned from this enumerator will be reuses
 * unless you retain them, before calling nextObject again.
 */
+ (NSEnumerator *)processesEnumerater;

- (BOOL)isNoProcess;
- (BOOL)isSystemProcess;
- (BOOL)isValid;								// attempts to get ProcessInfoRec and return true if no error

@end

@interface NDProcess (ProcessInfoRec)

- (NSString *)name;							//	processName
- (UInt32)type;								//	processType
- (OSType)signature;							//	processSignature
- (UInt32)mode;								//	processMode
- (NDProcess *)launcher;					//	processLauncher
- (NSTimeInterval)launchTime;				//	processLaunchDate
- (NSURL *)url;								//	processAppSpec
- (NSString *)path;							//	processAppSpec

@end